@@ -247,7 +247,9 @@ gail_window_real_initialize (AtkObject *obj,
       name = gtk_widget_get_name (widget);
       if (name && !strcmp (name, "gtk-tooltips"))
         obj->role = ATK_ROLE_TOOL_TIP;
-      else 
+      else if (GTK_IS_PLUG (widget))
+        obj->role = ATK_ROLE_PANEL;
+      else
         obj->role = ATK_ROLE_FRAME;
     }
   else if (GTK_IS_HANDLE_BOX (widget))
@@ -556,7 +558,8 @@ get_window_desktop (Window window)
                                &ret_type, &format, &nitems,
                                &bytes_after, (guchar **) &cardinals);
   error = gdk_error_trap_pop();
-  if (error != Success || result != Success)
+  /* nitems < 1 will occur if the property is not set */
+  if (error != Success || result != Success || nitems < 1)
     return -1;
 
   desktop = *cardinals;
@@ -611,7 +614,8 @@ get_stacked_windows (GailScreenInfo *info)
                                False, XA_WINDOW, &ret_type, &format, &nitems,
                                &bytes_after, (guchar **)&data);
   error = gdk_error_trap_pop ();
-  if (error != Success || result != Success)
+  /* nitems < 1 will occur if the property is not set */
+  if (error != Success || result != Success || nitems < 1)
     {
       free_screen_info (info);
       return FALSE;
